@@ -76,7 +76,7 @@ format_full_pillar_type <- function(x) {
 #' @export
 #' @examples
 #' # Default method: show the type with angle brackets
-#' format_type_sum(1, NULL)
+#' writeLines(format_type_sum("dbl", width = NULL))
 #' pillar(1)
 #'
 #' # AsIs method: show the type without angle brackets
@@ -84,6 +84,10 @@ format_full_pillar_type <- function(x) {
 #'   I("kg m/s^2")
 #' }
 #'
+#' # Typically done through NAMESPACE
+#' # (perhaps with an @export directive in roxygen2)
+#' registerS3method("type_sum", "accel", type_sum.accel)
+#'
 #' accel <- structure(9.81, class = "accel")
 #' pillar(accel)
 format_type_sum <- function(x, width, ...) {
@@ -94,11 +98,6 @@ format_type_sum <- function(x, width, ...) {
   UseMethod("format_type_sum")
 }
 
-# https://github.com/r-lib/pkgdown/issues/1540
-type_sum.accel <- function(x) {
-  I("kg m/s^2")
-}
-
 #' @export
 #' @rdname format_type_sum
 format_type_sum.default <- function(x, width, ...) {
